@@ -519,7 +519,7 @@ function dcpParseFlat(data,opts) {
 	dlabels.push(p.label);
 	pscores = p[p.score];
 
-	for (item in pscores) {
+	for (var item in pscores) {
 	    if ((iid=itemid[item]) != null) {
 		//-- existing item
 		idata = items[iid];
@@ -2277,13 +2277,13 @@ function escapeDDC(s, enquote) {
 function keys(obj) {
     if (!(obj instanceof Object)) { return []; }
     var keys = [];
-    for (k in obj) { keys.push(k);  }
+    for (var k in obj) { keys.push(k);  }
     return keys;
 }
 function values(obj) {
     if (!(obj instanceof Object)) { return []; }
     var vals = [];
-    for (k in obj) { vals.push(obj[k]); }
+    for (var k in obj) { vals.push(obj[k]); }
     return vals;
 }
 
